## 短期国债利率

接口：us_tbr

描述：获取美国短期国债利率数据

限量：单次最大可获取2000行数据，可循环获取

权限：用户积累120积分可以使用，积分越高频次越高。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| date | str | N | 日期 |
| start_date | str | N | 开始日期(YYYYMMDD格式) |
| end_date | str | N | 结束日期 |
| fields | str | N | 指定输出字段(e.g. fields='w4_bd,w52_ce') |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| date | str | Y | 日期 |
| w4_bd | float | Y | 4周银行折现收益率 |
| w4_ce | float | Y | 4周票面利率 |
| w8_bd | float | Y | 8周银行折现收益率 |
| w8_ce | float | Y | 8周票面利率 |
| w13_bd | float | Y | 13周银行折现收益率 |
| w13_ce | float | Y | 13周票面利率 |
| w17_bd | float | Y | 17周银行折现收益率（数据从20221019开始） |
| w17_ce | float | Y | 17周票面利率（数据从20221019开始） |
| w26_bd | float | Y | 26周银行折现收益率 |
| w26_ce | float | Y | 26周票面利率 |
| w52_bd | float | Y | 52周银行折现收益率 |
| w52_ce | float | Y | 52周票面利率 |

接口调用

```python
pro = ts.pro_api()

df = pro.us_tbr(start_date='20180101', end_date='20200327')


#获取指定字段数据
df = pro.us_tbr(start_date='20180101', end_date='20200327', fields='w4_bd,w52_ce')
```

数据样例

```python
date  w4_bd  w4_ce  w8_bd  w8_ce w13_bd w13_ce w26_bd w26_ce w52_bd w52_ce
0     20200327   0.01   0.01   0.03   0.03   0.03   0.03   0.02   0.02   0.11   0.11
```